datasource_session library

Classes

Codable<T, Self extends Codable<T, Self>>
The base contract for all data models or objects that require mapping from a remote representation to a local Dart object (decoding/deserialization).
DatasourceSessionDelete<RemoteObject extends Codable<Object, RemoteObject>>
A session-aware remote datasource for DELETE operations.
DatasourceSessionGet<RemoteObject extends Codable<Object, RemoteObject>>
A session-aware remote datasource for GET operations.
DatasourceSessionPatch<RemoteObject extends Codable<Object, RemoteObject>>
A session-aware remote datasource for PATCH operations.
DatasourceSessionPost<RemoteObject extends Codable<Object, RemoteObject>>
A session-aware remote datasource for POST operations.
DatasourceSessionPut<RemoteObject extends Codable<Object, RemoteObject>>
A session-aware remote datasource for PUT operations.