host property
String
get
host
host of the provide information, can contains port and scheme
Implementation
String get host;
host of the provide information, can contains port and scheme
String get host;