client property
CustomClient
client
final
The underlying ncc client responsible for executing the network calls.
Implementation
final CustomClient client;
The underlying ncc client responsible for executing the network calls.
final CustomClient client;