NetworkObserver class abstract interface

An abstract interface that defines the methods for observing network events and responses in the context of a BaseClient. Implementing this interface allows the observer to receive notifications about changes in network status, errors, and responses.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Dispose of resources when the observer is no longer needed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChangeNetworkStatus({required BaseClient client, required NetworkState previousState, required NetworkState currentState}) → void
Notifies the observer about a change in the network status.
onError({required BaseClient client, required Object error, required StackTrace? stackTrace}) → void
Notifies the observer when an error occurs during a network request.
onResponse({required BaseClient client, required OnResponse response}) → void
Notifies the observer when a network response has been received.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited