RemoteDriver<OriginalResponse> class abstract interface

An abstract interface that defines the contract for HTTP communication.

This driver decouples the DatasourceRemote from the underlying HTTP client implementation (e.g., http, dio, graphql). It provides explicit methods for standard HTTP verbs to facilitate debugging and clearer stack traces.

Inheritance
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(Uri url, {Map<String, String>? headers, Object? body, Encoding? encoding, Object? options}) Future<RequestResponse<OriginalResponse>>
Sends an HTTP DELETE request to remove a resource.
get(Uri url, {Map<String, String>? headers, Object? options}) Future<RequestResponse<OriginalResponse>>
Sends an HTTP GET request to retrieve data.
Sends an HTTP HEAD request.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Uri url, {Map<String, String>? headers, Object? body, Encoding? encoding, Object? options}) Future<RequestResponse<OriginalResponse>>
Sends an HTTP PATCH request to modify a resource partially.
post(Uri url, {Map<String, String>? headers, Object? body, Encoding? encoding, Object? options}) Future<RequestResponse<OriginalResponse>>
Sends an HTTP POST request to submit data.
put(Uri url, {Map<String, String>? headers, Object? body, Encoding? encoding, Object? options}) Future<RequestResponse<OriginalResponse>>
Sends an HTTP PUT request to replace a resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited