datasource_http library
Classes
-
Codable<
T, Self extends Codable< T, Self> > - The base contract for all data models or objects that require mapping from a remote representation to a local Dart object (decoding/deserialization).
-
DatasourceHttpDelete<
RemoteObject extends Codable< Object, RemoteObject> > - A standard remote datasource for DELETE operations using HttpDataShaftDriver.
-
DatasourceHttpGet<
RemoteObject extends Codable< Object, RemoteObject> > - A standard remote datasource for GET operations using HttpDataShaftDriver.
-
DatasourceHttpPatch<
RemoteObject extends Codable< Object, RemoteObject> > - A standard remote datasource for PATCH operations using HttpDataShaftDriver.
-
DatasourceHttpPost<
RemoteObject extends Codable< Object, RemoteObject> > - A standard remote datasource for POST operations using HttpDataShaftDriver.
-
DatasourceHttpPut<
RemoteObject extends Codable< Object, RemoteObject> > - A standard remote datasource for PUT operations using HttpDataShaftDriver.