datasource_http library

Classes

Codable<T, Self extends Codable<T, Self>>
The base contract for all data models or objects that require mapping from a remote representation to a local Dart object (decoding/deserialization).
DatasourceDeleteHttp<RemoteObject extends Codable<Object, RemoteObject>>
A standard remote datasource for DELETE operations using HttpDataShaftDriver.
DatasourceGetHttp<RemoteObject extends Codable<Object, RemoteObject>>
A standard remote datasource for GET operations using HttpDataShaftDriver.
DatasourcePatchHttp<RemoteObject extends Codable<Object, RemoteObject>>
A standard remote datasource for PATCH operations using HttpDataShaftDriver.
DatasourcePostHttp<RemoteObject extends Codable<Object, RemoteObject>>
A standard remote datasource for POST operations using HttpDataShaftDriver.
DatasourcePutHttp<RemoteObject extends Codable<Object, RemoteObject>>
A standard remote datasource for PUT operations using HttpDataShaftDriver.