DatasourceNccPost<RemoteObject extends Codable<Object, RemoteObject> , NccDriver extends NccConnectionDriver<BaseClient> > class
abstract
base
A specialized remote datasource for POST operations using an NccConnectionDriver.
This class provides the base implementation for creating new resources
on a remote server. It combines data_shaft's standardized creation flow
with the networking features provided by the ncc client.
RemoteObject handles the serialization of the new resource and
deserialization of the server response, while NccDriver manages
the network execution.
- Inheritance
-
- Object
- DataSource
- DataSourceCallable<
RemoteObject> - DatasourceRemote<
RemoteObject, NccDriver> - DatasourcePostRemote<
RemoteObject, NccDriver> - DatasourceNccPost
- Implementers
Constructors
- DatasourceNccPost({required NccDriver driver})
- A specialized remote datasource for POST operations using an NccConnectionDriver.
Properties
-
admissibleStatusCode
→ List<
int> -
List of http status code with the admissible status codes.
no setterinherited
- driver → NccDriver
-
The underlying RemoteDriver instance used to execute remote operations.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
host of the provide information, can contains port and scheme
no setterinherited
-
inadmissibleStatusCode
→ List<
int> -
List of http status code with the inadmissible status codes.
no setterinherited
- observer → HttpDatasourceObserver
-
Retrieves the standard observer instance used to track the lifecycle
and events of all Data Sources in the application.
no setterinherited
- path → String?
-
path of the provide information
no setterinherited
-
pathModification
→ Map<
String, String> -
path of the provide information
no setterinherited
- pathPrefix → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → Uri
-
Current url transformation to URI.
no setterinherited
Methods
-
call(
{required covariant Params params}) → Future< RemoteObject> -
Manage the server connection.
inherited
-
checkInformation(
{required covariant RequestResponse< Response> requestResponse, required Map<String, String> ? requestHeaders, required Uri? requestUri, Object? requestBody}) → FutureOr<RemoteObject> -
Usually use after server call to return the required data or failure.
override
-
dispose(
) → void -
Called when the DataSource instance is no longer needed and should
release any held resources (e.g., closing connections, unregistering listeners).
inherited
-
generateCallRequirement(
{required covariant Params params}) → PostParams -
Generates the specific parameters required for a POST request.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
request(
RequestParams requestParams) → Future< RemoteObject> -
Centralized method to handle all HTTP requests.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transformation(
{required covariant RequestResponse< Response> remoteResponse}) → FutureOr<RemoteObject> -
Function call after response success.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited