NetworkAvailabilityException class base
Exception thrown when there is a network availability issue, such as when the device is offline or cannot reach the server.
This class represents errors that are specifically related to the unavailability of the network. For example, if the device cannot connect to the internet or if there are connection timeout issues.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited