dispose abstract method
void
dispose()
Dispose of resources when the observer is no longer needed.
This method is used to clean up any resources or listeners associated with the observer when it is no longer required or is being destroyed.
Implementation
void dispose();